@@ -33,7 +33,11 @@ if (dvb_debug>1) _fn_end(_name, err) ;
 #define MAX_ADAPTERS	4
 #define MAX_FRONTENDS	4
 
+/* ----------------------------------------------------------------------- */
+// FUNCTIONS
+/* ----------------------------------------------------------------------- */
 
+int setNonblocking(int fd) ;
 
 /* ----------------------------------------------------------------------- */
 // PERL INTERFACE
